==> converter-0.2.0.tar.gz: test/quantities/base/time_testcase.dart <==
import 'package:converter/converter.dart';

final Map<String, dynamic> timeConverter = <String, dynamic>{
  'testCases': <Map<String, dynamic>>[
    <String, dynamic>{
      'quantity': Time.si(17),
      'magnitudeInSI': 17,
      'magnitudeIn': <String, num>{
        's': 17,
        'ds': 170,
        'cs': 1700,
        'ms': 1.7e4,
        'µs': 1.7e7,
        'ns': 1.7e10,
        'das': 1.7,
        'hs': 0.17,
        'ks': 0.017,
        'Ms': 1.7e-5,
        'Gs': 1.7e-8,
        'min': 0.2833333,
        'h': 0.00472222,
        'd': 1.967593e-4,
        'wk': 2.810846e-5,
        'fn': 1.405423e-5,
        'mo': 6.464503e-6,
        'y': 5.387085e-7,
        'dec': 5.387085e-8,
        'c': 5.387085e-9,
      },
    },
    <String, dynamic>{
      'quantity': Time(19, 'ns'),
      'magnitudeInSI': 1.9e-8,
      'magnitudeIn': <String, num>{
        's': 1.9e-8,
        'ds': 1.9e-7,
        'cs': 1.9e-6,
        'ms': 1.9e-5,
        'µs': 0.019,
        'ns': 19,
        'das': 1.9e-9,
        'hs': 1.9e-10,
        'ks': 1.9e-11,
        'Ms': 1.9e-14,
        'Gs': 1.9e-17,
        'min': 3.166666e-10,
        'h': 5.277777e-12,
        'd': 2.199074e-13,
        'wk': 3.141534e-14,
        'fn': 1.570767e-14,
        'mo': 7.225032e-15,
        'y': 6.020860e-16,
        'dec': 6.020860e-17,
        'c': 6.020860e-18,
      },
    },
    <String, dynamic>{
      'quantity': Time(23, 'Gs'),
      'magnitudeInSI': 2.3e10,
      'magnitudeIn': <String, num>{
        's': 2.3e10,
        'ds': 2.3e11,
        'cs': 2.3e12,
        'ms': 2.3e13,
        'µs': 2.3e16,
        'ns': 2.3e19,
        'das': 2.3e9,
        'hs': 2.3e8,
        'ks': 2.3e7,
        'Ms': 2.3e4,
        'Gs': 23,
        'min': 3.833333e8,
        'h': 6.388888e6,
        'd': 2.662037e5,
        'wk': 3.802910e4,
        'fn': 1.901455e4,
        'mo': 8746.091828,
        'y': 728.840985,
        'dec': 72.884098,
        'c': 7.288409,
      },
    },
  ],
};

==> converter-0.3.4.tar.gz: test/quantities/base/time_testcase.dart <==
import 'package:converter/converter.dart';

final Map<String, dynamic> timeConverter = <String, dynamic>{
  'testCases': <Map<String, dynamic>>[
    <String, dynamic>{
      'quantity': Time.si(17),
      'siValue': 17,
      'valueIn': <String, num>{
        's': 17,
        'ds': 170,
        'cs': 1700,
        'ms': 1.7e4,
        'µs': 1.7e7,
        'ns': 1.7e10,
        'das': 1.7,
        'hs': 0.17,
        'ks': 0.017,
        'Ms': 1.7e-5,
        'Gs': 1.7e-8,
        'min': 0.2833333,
        'h': 0.00472222,
        'd': 1.967593e-4,
        'wk': 2.810846e-5,
        'fn': 1.405423e-5,
        'mo': 6.464503e-6,
        'y': 5.387085e-7,
        'dec': 5.387085e-8,
        'c': 5.387085e-9,
      },
    },
    <String, dynamic>{
      'quantity': Time(19, 'ns'),
      'siValue': 1.9e-8,
      'valueIn': <String, num>{
        's': 1.9e-8,
        'ds': 1.9e-7,
        'cs': 1.9e-6,
        'ms': 1.9e-5,
        'µs': 0.019,
        'ns': 19,
        'das': 1.9e-9,
        'hs': 1.9e-10,
        'ks': 1.9e-11,
        'Ms': 1.9e-14,
        'Gs': 1.9e-17,
        'min': 3.166666e-10,
        'h': 5.277777e-12,
        'd': 2.199074e-13,
        'wk': 3.141534e-14,
        'fn': 1.570767e-14,
        'mo': 7.225032e-15,
        'y': 6.020860e-16,
        'dec': 6.020860e-17,
        'c': 6.020860e-18,
      },
    },
    <String, dynamic>{
      'quantity': Time(23, 'Gs'),
      'siValue': 2.3e10,
      'valueIn': <String, num>{
        's': 2.3e10,
        'ds': 2.3e11,
        'cs': 2.3e12,
        'ms': 2.3e13,
        'µs': 2.3e16,
        'ns': 2.3e19,
        'das': 2.3e9,
        'hs': 2.3e8,
        'ks': 2.3e7,
        'Ms': 2.3e4,
        'Gs': 23,
        'min': 3.833333e8,
        'h': 6.388888e6,
        'd': 2.662037e5,
        'wk': 3.802910e4,
        'fn': 1.901455e4,
        'mo': 8746.091828,
        'y': 728.840985,
        'dec': 72.884098,
        'c': 7.288409,
      },
    },
  ],
};
